import '@polymer/paper-button/paper-button.js';
import '@polymer/paper-checkbox/paper-checkbox.js';
import '@polymer/paper-input/paper-input.js';
import '@polymer/paper-radio-button/paper-radio-button.js';
import '@polymer/paper-radio-group/paper-radio-group.js';
import { html } from 'lit-element'; 
import { connect } from 'pwa-helpers';
import { store } from '../store.js';
import { BaseView } from './base-view.js';
import { VisibilityFilters, getVisibleTodosSelector } from '../reducers/reducer.js';
import {
  addTodo,
  updateTodoStatus,
  updateFilter,
  clearCompleted
} from '../actions/todo.js';

  
class TodoView extends connect(store)(BaseView) {
  
    static get properties() { 
      return {
        todos: { type: Array },
        filter: { type: String },
        task: { type: String }
      };
    }
  
    stateChanged(state) { 
      console.log('state',state);
      this.todos = getVisibleTodosSelector(state);
      console.log('this.todos',this.todos);
      this.filter = state.filter;
    }
  
    render() {
      this.todos = [];
      return html`
      <style>
        todo-view { 
            display: block;
            max-width: 800px;
            margin: 0 auto;
        }
        todo-view .input-layout {
            width: 100%;
            display: flex;
        }
        todo-view .input-layout vaadin-text-field {
            flex: 1;
            margin-right: var(--spacing); 
        }
        todo-view .todos-list {
            margin-top: var(--spacing);
        }
        todo-view .visibility-filters {
            margin-top: calc(4 * var(--spacing));
        }
        </style>
        <div class="input-layout"
            @keyup="${this.shortcutListener}"> 
            
            <paper-input
                placeholder="Task"
                value="${this.task || ''}" 
                @change="${this.updateTask}"> 
            </paper-input>
            
            <paper-button class="pink"
                theme="primary"
                @click="${this.addTodo}"> 
                Add Todo
            </paper-button>
        </div>

        <div class="todos-list">
        ${this.todos.map(
            todo => html` 
                <div class="todo-item">
                <paper-checkbox 
                    ?checked="${todo.complete}" 
                    @change="${ e => this.updateTodoStatus(todo, e.target.checked)}"> 
                    ${todo.task}
                </paper-checkbox>
                </div>
            `
            )
        }
        </div>

        <paper-radio-group
        class="visibility-filters"
        selected="${this.filter}"
        @change="${this.filterChanged}"> 

        ${Object.values(VisibilityFilters).map( 
            filter => html`
            <paper-radio-button name="${filter}">
                ${filter}
            </paper-radio-button>`
        )}
        </paper-radio-group>
        <paper-button class="pink"
        @click="${this.clearCompleted}"> 
            Clear completed
        </paper-button>
        
      `;
    }

    addTodo() {
        if (this.task) {
          store.dispatch(addTodo(this.task));
          this.task = ''; 
        }
      }
    
      shortcutListener(e) {
        if (e.key === 'Enter') { 
          this.addTodo();
        }
      }
    
      updateTask(e) {
        this.task = e.target.value; 
      }

      updateTodoStatus(updatedTodo, complete) {
        store.dispatch(updateTodoStatus(updatedTodo, complete));
      }

      filterChanged(e) { 
        store.dispatch(updateFilter(e.target.name));
      }
    
      clearCompleted() { 
        store.dispatch(clearCompleted());
      }
    
      applyFilter(todos) { 
        switch (this.filter) {
          case VisibilityFilters.SHOW_ACTIVE:
            return todos.filter(todo => !todo.complete);
          case VisibilityFilters.SHOW_COMPLETED:
            return todos.filter(todo => todo.complete);
          default:
            return todos;
        }
      }

      createRenderRoot() {
        return this;
    }
  }

customElements.define('todo-view', TodoView);